@@ -4,7 +4,7 @@ package WebService::Avalara::AvaTax;
 
 use Modern::Perl '2011';    ## no critic (Modules::ProhibitUseQuotedVersion)
 
-our $VERSION = '0.016';     # VERSION
+our $VERSION = '0.018';     # VERSION
 use utf8;
 
 #pod =head1 SYNOPSIS
@@ -125,7 +125,7 @@ sub _new_service {
 #pod SOAP operation names have been transformed from C<CamelCase> to
 #pod C<lowercase_with_underscores>. For example, C<GetTax> is now
 #pod L</get_tax>. If you do not like this behavior then use
-#pod C<< L</orthodox> => 1 >> when calling L</new>.
+#pod L<<< C<< orthodox => 1 >>|/orthodox >>> when calling L</new>.
 #pod
 #pod =item *
 #pod
@@ -273,7 +273,7 @@ WebService::Avalara::AvaTax - Avalara SOAP interface as compiled Perl methods
 
 =head1 VERSION
 
-version 0.016
+version 0.018
 
 =head1 SYNOPSIS
 
@@ -323,7 +323,7 @@ and more Perl-ish, the following changes have been made:
 SOAP operation names have been transformed from C<CamelCase> to
 C<lowercase_with_underscores>. For example, C<GetTax> is now
 L</get_tax>. If you do not like this behavior then use
-C<< L</orthodox> => 1 >> when calling L</new>.
+L<<< C<< orthodox => 1 >>|/orthodox >>> when calling L</new>.
 
 =item *
 
