@@ -4,7 +4,7 @@ package WebService::Avalara::AvaTax::Role::Connection;
 
 use Modern::Perl '2011';    ## no critic (Modules::ProhibitUseQuotedVersion)
 
-our $VERSION = '0.016';     # VERSION
+our $VERSION = '0.018';     # VERSION
 use utf8;
 
 #pod =head1 SYNOPSIS
@@ -113,7 +113,7 @@ has debug => (
 #pod If you do not specify a C<user_agent> then we default to an instance of
 #pod L<LWPx::UserAgent::Cached|LWPx::UserAgent::Cached>. Note that we also set
 #pod the C<HTTPS_CA_FILE> environment variable to the result from
-#pod L<Mozilla::CA::SSL_ca_file|Mozilla::CA/SSL_ca_file> in order to correctly
+#pod L<Mozilla::CA::SSL_ca_file|Mozilla::CA> in order to correctly
 #pod resolve certificate names.
 #pod
 #pod =cut
@@ -226,7 +226,7 @@ WebService::Avalara::AvaTax::Role::Connection - Common attributes and methods fo
 
 =head1 VERSION
 
-version 0.016
+version 0.018
 
 =head1 SYNOPSIS
 
@@ -285,7 +285,7 @@ use your own subclass to add features such as caching or enhanced logging.
 If you do not specify a C<user_agent> then we default to an instance of
 L<LWPx::UserAgent::Cached|LWPx::UserAgent::Cached>. Note that we also set
 the C<HTTPS_CA_FILE> environment variable to the result from
-L<Mozilla::CA::SSL_ca_file|Mozilla::CA/SSL_ca_file> in order to correctly
+L<Mozilla::CA::SSL_ca_file|Mozilla::CA> in order to correctly
 resolve certificate names.
 
 =head2 wsdl
